package com.frank01001.hydrogentech;

import buildcraft.api.fuels.IronEngineFuel;

import com.frank01001.hydrogentech.blocks.*;
import com.frank01001.hydrogentech.handlers.BucketHandler;
import com.frank01001.hydrogentech.handlers.FuelHandler;
import com.frank01001.hydrogentech.items.*;

import net.minecraft.block.Block;
import net.minecraft.block.material.Material;
import net.minecraft.creativetab.CreativeTabs;
import net.minecraft.init.Blocks;
import net.minecraft.init.Items;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.util.IIcon;
import net.minecraftforge.common.MinecraftForge;
import net.minecraftforge.fluids.Fluid;
import net.minecraftforge.fluids.FluidContainerRegistry;
import net.minecraftforge.fluids.FluidRegistry;
import cpw.mods.fml.common.Loader;
import cpw.mods.fml.common.Mod;
import cpw.mods.fml.common.Mod.EventHandler;
import cpw.mods.fml.common.event.FMLInitializationEvent;
import cpw.mods.fml.common.event.FMLPostInitializationEvent;
import cpw.mods.fml.common.event.FMLPreInitializationEvent;
import cpw.mods.fml.common.registry.GameRegistry;
import cpw.mods.fml.common.registry.LanguageRegistry;
import ic2.api.item.IC2Items;
import ic2.api.recipe.*;

@Mod(modid = HydrogenTech.MODID, version = HydrogenTech.VERSION, name = "Hydrogen Tech")
public class HydrogenTech
{
    public static final String MODID = "hydrogentech";
    public static final String VERSION = "1.0";
    
    public static Item hydCell;
    public static Item divCell;
    public static Item hydCircuit;
    public static Item hydBucket;
    
    public Fluid hyd;
    
    public static CreativeTabs hydTab = new CreativeTabs("hydrogentab"){

		public Item getTabIconItem() {
			
			return hydCell;
			
		}
    	
    };
    
    public static Block hydJump;
    public Block hydBlock;
    
    @EventHandler 
    public void preInit(FMLPreInitializationEvent event) {
    	
    	System.out.println("HydrogenTech: Loading...");
    	System.out.println("HydrogenTech: Initializing Blocks.");
    	initializeBlocks();
    	System.out.println("HydrogenTech: Initializing Items.");
    	initializeItems();
    	System.out.println("HydrogenTech: Initializing handlers.");
    	initializeHandlers();
    	if (Loader.isModLoaded("BuildCraft|Energy")) {
            try {
               
            	IronEngineFuel.addFuel("hydrogenfluid", 48, 800000);
            	
                System.out.println("HydrogenTech: Found Buildcraft, Initializing.");
            
            }
            catch (Exception e) {
                e.printStackTrace();
            }
        
		}else{
			
			System.out.println("HydrogenTech: Didn't find Buildcraft");
			
		}
    	
    }
    
    @EventHandler
    public void load(FMLInitializationEvent event) {
            
    	System.out.println("HydrogenTech: Initializing Recipes");
    	initializeRecipes();
    	LanguageRegistry.instance().addStringLocalization("itemGroup.hydrogentab", "en_US", "Hydrogen Tech");
            
    }
    

    public void postInit(FMLPostInitializationEvent event) {
            
    	
    	
    }
    
    public void initializeItems(){
    	
    	hydCell = new ItemHydrogenCell();
    	divCell = new ItemDividedCell();
    	hydCircuit = new ItemHydrogenCircuit();
    	hydBucket = new ItemHydrogenBucket(hydBlock);
    	GameRegistry.registerItem(hydCell, hydCell.getUnlocalizedName());
    	GameRegistry.registerItem(divCell, divCell.getUnlocalizedName());
    	GameRegistry.registerItem(hydCircuit, hydCircuit.getUnlocalizedName());
    	GameRegistry.registerItem(hydBucket, hydBucket.getUnlocalizedName());
    	LanguageRegistry.addName(hydCell, "Hydrogen Cell");
    	LanguageRegistry.addName(divCell, "Divided Eletrolized Water Cell");
    	LanguageRegistry.addName(hydCircuit, "Hydrogen Circuit");
    	LanguageRegistry.addName(hydBucket, "Hydrogen Bucket");
    	FluidContainerRegistry.registerFluidContainer(FluidRegistry.getFluidStack(hyd.getName(), FluidContainerRegistry.BUCKET_VOLUME), new ItemStack(hydBucket), new ItemStack(Items.bucket));
    	
    }
    
    public void initializeBlocks(){
    	
    	hydJump = new BlockHydrogenJumper(Material.iron).setHardness(1.0F).setStepSound(Block.soundTypeMetal);
    	hyd = new Fluid("hydrogen").setDensity(71).setTemperature(20).setUnlocalizedName("hydrogenfluid");
    	FluidRegistry.registerFluid(hyd);
    	hydBlock = new BlockHydrogen(hyd, Material.water);
    	hyd.setBlock(hydBlock);
    	GameRegistry.registerBlock(hydJump, hydJump.getUnlocalizedName());
    	GameRegistry.registerBlock(hydBlock, hydBlock.getUnlocalizedName());
    	LanguageRegistry.addName(hydJump, "Hydrogen Jumper");
    	LanguageRegistry.addName(hydBlock, "Hydrogen Liquid");
    	
    	
    }
    
    public void initializeRecipes(){
    	
    	GameRegistry.addShapelessRecipe(new ItemStack(hydCell, 1), new ItemStack(divCell));
    	Recipes.extractor.addRecipe(new RecipeInputItemStack(IC2Items.getItem("electrolyzedWaterCell")), null, new ItemStack(divCell, 1));
    	GameRegistry.addRecipe(new ItemStack(hydCircuit, 1), "chc", "rir", "cgc", 'c', IC2Items.getItem("insulatedGoldCableItem"), 'h', hydCell, 'r', Items.redstone, 'i', IC2Items.getItem("electronicCircuit"), 'g', Items.glowstone_dust);
    	GameRegistry.addRecipe(new ItemStack(hydJump, 1), " h ", "cbc", "   ", 'h', hydCell, 'c', hydCircuit, 'b', IC2Items.getItem("machine"));
    
    }
    
    public void initializeHandlers(){
    	
    	BucketHandler.INSTANCE.buckets.put(hydBlock, hydBucket);
    	MinecraftForge.EVENT_BUS.register(BucketHandler.INSTANCE);
    	GameRegistry.registerFuelHandler(new FuelHandler());
    	
    }
    
}
